@@ -11,11 +11,24 @@ try:
 except ImportError:  # Python < 2.5
     from email.Utils import parsedate
 
+from httpexceptor import HTTP415, HTTP400
+
 from tiddlyweb.serializer import Serializer
-from tiddlyweb.web.http import HTTP415, HTTP400
 from tiddlyweb.util import sha
 
 
+def check_last_modified(environ, last_modified_string):
+    """
+    Raise `HTTP304` if If-Modified-Since header matches `last_modified_string`
+    """
+    incoming_modified = environ.get('HTTP_IF_MODIFIED_SINCE', None)
+    if incoming_modified:
+        incoming_modified = datetime_from_http_date(incoming_modified)
+        if incoming_modified and (incoming_modified >=
+                datetime_from_http_date(last_modified_string)):
+            raise HTTP304('')
+
+
 def content_length_and_type(environ):
     """
     To PUT or POST we must have content-length and content-type
@@ -47,17 +60,24 @@ def get_route_value(environ, name):
     return value
 
 
-def get_serialize_type(environ):
+def get_serialize_type(environ, collection=False):
     """
     Look in the environ to determine which serializer
     we should use for this request.
+
+    If collection is True, then the presence of an extension which
+    does not match any serializer should lead to a 415.
     """
     config = environ['tiddlyweb.config']
     accept = environ.get('tiddlyweb.type')[:]
     ext = environ.get('tiddlyweb.extension')
+    extension_types = config['extension_types']
     serializers = config['serializers']
     serialize_type, mime_type = None, None
 
+    if collection and ext and ext not in extension_types:
+        accept = [None]
+
     if type(accept) == str:
         accept = [accept]
 
